/*
 * Segment 8 Parametrierung und Konfiguration, SWE 8.2 Parametrierung - Bibliothek
 * Copyright (C) 2007-2015 BitCtrl Systems GmbH
 *
 * This program is free software; you can redistribute it and/or modify it under
 * the terms of the GNU Lesser General Public License as published by the Free
 * Software Foundation; either version 2.1 of the License, or (at your option)
 * any later version.
 *
 * This program is distributed in the hope that it will be useful, but WITHOUT
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
 * FOR A PARTICULAR PURPOSE. See the GNU Lesser General Public License for more
 * details.
 *
 * You should have received a copy of the GNU Lesser General Public License
 * along with this program; if not, write to the Free Software Foundation, Inc.,
 * 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
 *
 * Contact Information:
 * BitCtrl Systems GmbH
 * Weißenfelser Straße 67
 * 04229 Leipzig
 * Phone: +49 341-490670
 * mailto: info@bitctrl.de
 */

package de.bsvrz.puk.param.lib;

import java.io.Serializable;

/**
 * die serialisierbare Form der Quellendefinition, d.h. der Definition des
 * Ursprungs der Daten für einen Parameterdatensatz.
 *
 * @author BitCtrl Systems GmbH, Peuker
 * @version $Id: SerializableQuelle.java 62370 2016-06-29 13:45:13Z peuker $
 */
final class SerializableQuelle implements Serializable {

	/** Versions-ID für die Serialisierung. */
	private static final long serialVersionUID = 1L;

	/**
	 * die ID des Systemobjekts, an dem die Daten eines Parameterdatensatzes
	 * ermittelt werden konnten.
	 */
	private final long objektId;

	/** der Typ der Quelle. */
	private final QuellTyp typ;

	/** sind Daten verfügbar? */
	private final boolean dataAvailable;

	/**
	 * erzeugt ein Instanz des Objekts auf Basis des übergebenen Objekts.
	 *
	 * @param quelle
	 *            die Quelle, aus der ein serialisierbares Objekt erzeugt werden
	 *            soll.
	 */
	SerializableQuelle(final Quelle quelle) {
		if (null != quelle.getObjekt()) {
			objektId = quelle.getObjekt().getId();
		} else {
			objektId = 0;
		}
		typ = quelle.getTyp();
		dataAvailable = quelle.isDataAvailable();
	}

	/**
	 * ermittelt, ob die Quelle potentiell Daten liefern könnte.
	 *
	 * @return den Zustand
	 */
	public boolean isDataAvailable() {
		return dataAvailable;
	}

	/**
	 * liefert die ID des Systemobjekts der Quelle.
	 *
	 * @return die ID
	 */
	long getObjektId() {
		return objektId;
	}

	/**
	 * liefert den Typ der Quelle.
	 *
	 * @return den Typ
	 */
	QuellTyp getTyp() {
		return typ;
	}
}
